.. expect: role missing opening tag colon

.. and yes, it looks like a default role, so:
.. expect: default role used

New Linux constants ``TCP_USER_TIMEOUT`` and ``TCP_CONGESTION`` were added.
(Contributed by Omar Sandoval, issue:`26273`).
